Merge "Correct comments that refer to VP9."
diff --git a/vp10/common/x86/vp10_fwd_dct32x32_impl_sse2.h b/vp10/common/x86/vp10_fwd_dct32x32_impl_sse2.h
index 2490973..77f633e 100644
--- a/vp10/common/x86/vp10_fwd_dct32x32_impl_sse2.h
+++ b/vp10/common/x86/vp10_fwd_dct32x32_impl_sse2.h
@@ -3099,7 +3099,7 @@
             tr2_6 = _mm_sub_epi16(tr2_6, tr2_6_0);
             tr2_7 = _mm_sub_epi16(tr2_7, tr2_7_0);
             //           ... and here.
-            //           PS: also change code in vp9/encoder/vp9_dct.c
+            //           PS: also change code in vp10/encoder/dct.c
             tr2_0 = _mm_add_epi16(tr2_0, kOne);
             tr2_1 = _mm_add_epi16(tr2_1, kOne);
             tr2_2 = _mm_add_epi16(tr2_2, kOne);
diff --git a/vp10/decoder/decodeframe.c b/vp10/decoder/decodeframe.c
index d2e662f..6b5d146 100644
--- a/vp10/decoder/decodeframe.c
+++ b/vp10/decoder/decodeframe.c
@@ -1972,7 +1972,7 @@
         read_bitdepth_colorspace_sampling(cm, rb);
       } else {
         // NOTE: The intra-only frame header does not include the specification
-        // of either the color format or color sub-sampling in profile 0. VP9
+        // of either the color format or color sub-sampling in profile 0. VP10
         // specifies that the default color format should be YUV 4:2:0 in this
         // case (normative).
         cm->color_space = VPX_CS_BT_601;
diff --git a/vp10/decoder/decoder.c b/vp10/decoder/decoder.c
index ac26778..8144ef5 100644
--- a/vp10/decoder/decoder.c
+++ b/vp10/decoder/decoder.c
@@ -158,7 +158,7 @@
   /* TODO(jkoleszar): The decoder doesn't have any real knowledge of what the
    * encoder is using the frame buffers for. This is just a stub to keep the
    * vpxenc --test-decode functionality working, and will be replaced in a
-   * later commit that adds VP9-specific controls for this functionality.
+   * later commit that adds VP10-specific controls for this functionality.
    */
   if (ref_frame_flag == VPX_LAST_FLAG) {
     const YV12_BUFFER_CONFIG *const cfg = get_ref_frame(cm, 0);
@@ -190,7 +190,7 @@
   // TODO(jkoleszar): The decoder doesn't have any real knowledge of what the
   // encoder is using the frame buffers for. This is just a stub to keep the
   // vpxenc --test-decode functionality working, and will be replaced in a
-  // later commit that adds VP9-specific controls for this functionality.
+  // later commit that adds VP10-specific controls for this functionality.
   if (ref_frame_flag == VPX_LAST_FLAG) {
     ref_buf = &cm->frame_refs[0];
   } else if (ref_frame_flag == VPX_GOLD_FLAG) {
diff --git a/vp10/vp10_dx_iface.c b/vp10/vp10_dx_iface.c
index ad20d18..444c282 100644
--- a/vp10/vp10_dx_iface.c
+++ b/vp10/vp10_dx_iface.c
@@ -72,7 +72,7 @@
   // BufferPool that holds all reference frames. Shared by all the FrameWorkers.
   BufferPool              *buffer_pool;
 
-  // External frame buffer info to save for VP9 common.
+  // External frame buffer info to save for VP10 common.
   void *ext_priv;  // Private data associated with the external frame buffers.
   vpx_get_frame_buffer_cb_fn_t get_ext_fb_cb;
   vpx_release_frame_buffer_cb_fn_t release_ext_fb_cb;
diff --git a/vp10/vp10_cx_iface.c b/vp10/vp10_cx_iface.c
index 9e38e23..8dfe1f9 100644
--- a/vp10/vp10_cx_iface.c
+++ b/vp10/vp10_cx_iface.c
@@ -198,7 +198,7 @@
   // Only accept the default value for range checking.
   RANGE_CHECK(cfg, ss_number_layers, 1, 1);
   RANGE_CHECK(cfg, ts_number_layers, 1, 1);
   // VP9 does not support a lower bound on the keyframe interval in
   // automatic keyframe placement mode.
   if (cfg->kf_mode != VPX_KF_DISABLED &&
       cfg->kf_min_dist != cfg->kf_max_dist &&
@@ -220,9 +220,9 @@
   RANGE_CHECK(extra_cfg, content,
               VPX_CONTENT_DEFAULT, VPX_CONTENT_INVALID - 1);
 
   // TODO(yaowu): remove this when ssim tuning is implemented for vp9
   if (extra_cfg->tuning == VPX_TUNE_SSIM)
-      ERROR("Option --tune=ssim is not currently supported in VP9.");
+      ERROR("Option --tune=ssim is not currently supported in VP10.");
 
   if (cfg->g_pass == VPX_RC_LAST_PASS) {
     const size_t packet_sz = sizeof(FIRSTPASS_STATS);
@@ -429,7 +429,7 @@
   oxcf->frame_periodic_boost =  extra_cfg->frame_periodic_boost;
 
   /*
-  printf("Current VP9 Settings: \n");
+  printf("Current VP10 Settings: \n");
   printf("target_bandwidth: %d\n", oxcf->target_bandwidth);
   printf("noise_sensitivity: %d\n", oxcf->noise_sensitivity);
   printf("sharpness: %d\n",    oxcf->sharpness);
@@ -854,7 +854,7 @@
   return index_sz;
 }
 
 // vp9 uses 10,000,000 ticks/second as time stamp
 #define TICKS_PER_SEC 10000000LL
 
 static int64_t timebase_units_to_ticks(const vpx_rational_t *timebase,
@@ -1143,7 +1143,7 @@
   (void)ctx;
   (void)args;
 
   // TODO(yaowu): Need to re-implement and test for VP9.
   return VPX_CODEC_INVALID_PARAM;
 }
 
@@ -198,7 +198,7 @@
   RANGE_CHECK(cfg, ss_number_layers, 1, 1);
   RANGE_CHECK(cfg, ts_number_layers, 1, 1);
-  // VP9 does not support a lower bound on the keyframe interval in
+  // VP10 does not support a lower bound on the keyframe interval in
   // automatic keyframe placement mode.
   if (cfg->kf_mode != VPX_KF_DISABLED &&
@@ -220,9 +220,9 @@
               VPX_CONTENT_DEFAULT, VPX_CONTENT_INVALID - 1);
 
-  // TODO(yaowu): remove this when ssim tuning is implemented for vp9
+  // TODO(yaowu): remove this when ssim tuning is implemented for vp10
   if (extra_cfg->tuning == VPX_TUNE_SSIM)
@@ -854,7 +854,7 @@
 }
 
-// vp9 uses 10,000,000 ticks/second as time stamp
+// vp10 uses 10,000,000 ticks/second as time stamp
 #define TICKS_PER_SEC 10000000LL
 
@@ -1143,7 +1143,7 @@
   (void)args;
 
-  // TODO(yaowu): Need to re-implement and test for VP9.
+  // TODO(yaowu): Need to re-implement and test for VP10.
   return VPX_CODEC_INVALID_PARAM;
 }